from setuptools import setup, find_packages

setup(
    name='helperforpy',
    version='0.1.0',
    description='Helperforpy package',
    packages=find_packages(),
    install_requires=[
        'numpy',
    ],
)
